﻿class Arret
{
	private var m_indice:Number; // Indice de l'arret. (Indice du xml, l'indice réel)
	private var m_numero_bus:Number; // Numero du bus qui va s'arreter.
	private var m_heure:Number; // Heure à laquelle le bus arrive à l'arret. (exprimée en ms).
	private var m_passagers:Array; // Contient l'ensemble des passagers ayant pour départ l'arret this.
	
	/**
	*	Constructeur
	*	A partir d'un noeud xml remplit les données de l'arret : le bus, l'heure
	*	d'arrivée et l'ensemble de passagers qui montent dans le bus à cet arret.
	*/
	public function Arret(noeud_arret:Array)
	{
		m_passagers = new Array();
		
		for(var i = 0; i < noeud_arret.childNodes.length; i++)
		{
			// Switch pour pouvoir faire le xml dans le désordre
			switch(noeud_arret.childNodes[i].nodeName)
			{
				case "indice_arret":
					m_indice = parseInt(noeud_arret.childNodes[i].firstChild.nodeValue);
					break;
				case "numero_bus":
					m_numero_bus = parseInt(noeud_arret.childNodes[i].firstChild.nodeValue);
					break;
				case "heure":
					var s = noeud_arret.childNodes[i].firstChild.nodeValue;
					var r = s.split(":");
					m_heure = (parseInt(r[0])*3600 + parseInt(r[1])*60 + parseInt(r[2]))*1000;
					break;
				case "nom_arret":
					break;
				case "passagers":
					var nb = noeud_arret.childNodes[i].attributes["nombre"];
					var type = noeud_arret.childNodes[i].attributes["type"];
					
					// Création du bon nombre de passagers de chaque type.
					for(var j = 0; j < parseInt(nb); j++)
						m_passagers.push(new Passager(type));
						
					break;					
				default:
					trace("Element inconnu : " + noeud_arret.childNodes[i].nodeName);
			}
		}
		
		// Affectation de l'arret courant comme arret de départ pour les passagers
		// L'arret d'arrivé est calculé aléatoirement ensuite.
		for(var k in m_passagers)
		{
			m_passagers[k].indiceDepart = m_indice;
		}
		
	}
	
	
	/**
	*	Accesseurs
	*/
	public function get passagers():Array
	{
		return m_passagers;
	}
	
	public function get indice():Number
	{
		return m_indice;
	}
	
	public function get heure():Number
	{
		return m_heure;
	}
	
	public function get numeroBus():Number
	{
		return m_numero_bus;
	}
	
	public function toString():String
	{
		return "Arret : " + m_indice + " Bus : " + m_numero_bus + " Heure : " + m_heure + " Passagers " + m_passagers;
	}
}
