﻿/** Class Ligne
*	Contient l'ensemble des bus qui vont se déplacer sur celle-ci.
*   Chaque ligne est définie séparement dans un fichier xml.
*/
class Ligne
{
	private var m_numero_ligne:Number; // Numero de la ligne.
	private var m_nom_guideline:String; // Nom du guide de base pour instancier les guides des bus de la ligne.
	private var m_nb_frames:Number; // Nombre de frames séparant 2 arrets sur le guide pour cette ligne (donnée xml).
	private var m_jours:Object; // Tableau associatif contenant pour chaque jour la liste des bus contenant eu meme leurs arrets.
	private var m_liste_jours:Array; // Liste brute des dates rencontrées, peut contenir des doublons.
	private var m_visible:Boolean = true; // True si la ligne doit etre affichée (mettre à fausse stop les calculs)
	private var m_mc_bus:Array; // Liste des movie clip représentant les bus de cette ligne (l'ensemble des guides).
	
	/** 
	* 	Rendre l'ensemble des bus visible/invisible sur la carte.
	*	b True pour rendre invisible, false sinon.
	*/
	public function setVisible(b:Boolean)
	{
		if(b == true)
		{
			for(var i in m_mc_bus)
			{
				m_mc_bus[i]._visible = true;
			}
			m_visible = true;
		}
		else
		{
			for(var i in m_mc_bus)
			{
				m_mc_bus[i]._visible = false;
			}
			m_visible = false;
		}
	}
	
	/**	
	*	Rend l'ensemble des bus insivible.
	*/
	private function resetGuides()
	{
		for(var i in m_mc_bus)
		{
				m_mc_bus[i]._visible = false;
		}
	}
	
	/**
	*	Constructeur
	*/
	public function Ligne(xml_path:String)
	{
		// Instanciation du tableau associatif.
		m_jours = new Object();
		
		// Instanciations.
		m_liste_jours = new Array();
		m_mc_bus = new Array();
		
		// Parser le xml
		if(loadXML(xml_path) == false) 
			trace("Problème au chargement du xml : " + xml_path + ".");
	}
	
	/**
	*	Rafraichir les bus de l'ensemble de la ligne fonction de l'heure.
	*/
	public function rafraichir(h:Number, date:String)
	{	
		// Remise à 0 de l'affichage
		resetGuides();
		if(m_jours[date] instanceof Array && m_visible)
			for(var i = 0; i < m_jours[date].length; i++)
			{
				if((m_jours[date][i] instanceof Bus))
				{
					// On appel rafrachir sur chaque bus de la ligne.
					// Ils seront alors positionés correctement et affichés si besoin.
					m_jours[date][i].rafraichir(h);
				}
			}
	}
	
	/** 
	* 	Charge la ligne à partir du fichier xml associé. Retourne true si 
	*	le chargement bien déroulé, false sinon.
	*/
	private function loadXML(xml_path:String):Boolean
	{
		var donnees_xml = new XML();
		donnees_xml.ignoreWhite = true;
		
		// Nécessaire pour éviter les confusions dans onLoad
		var thisObj = this;
		
		donnees_xml.onLoad = function(ok) 
		{
  			if (ok)
			{
	  			var racine = this.firstChild;
	  			for(var i = 0; i < racine.childNodes.length; i++)
	  			{
					// Switch pour pouvoir avoir un xml dans le désordre
		  			switch(racine.childNodes[i].nodeName)
					{
						case "numero_ligne":
							thisObj.m_numero_ligne = racine.childNodes[i].firstChild.nodeValue;
							break;
						case "nom_guideline":
							thisObj.m_nom_guideline = racine.childNodes[i].firstChild.nodeValue;
							break;
						case "nombre_frames":
							thisObj.m_nb_frames = racine.childNodes[i].firstChild.nodeValue;
							break;
						case "arrets":
							// Si arrets on s'attend à avoir un ensemble de "arret"
							var date_noeud = racine.childNodes[i].attributes.date;
							var node = racine.childNodes[i];
							
							thisObj.m_jours[date_noeud] = new Array();
							thisObj.m_liste_jours.push(date_noeud);
							
							for(var j = 0; j < node.childNodes.length; j++)
							{
								if(node.childNodes[j].nodeName == "arret")
								{								
									// On parse individuellement chaque arret en créeant un nouvel arret.
									var arret = new Arret(node.childNodes[j]);
									
									// On test si le guide du bus a déja été instancié.
									if(!(thisObj.m_jours[date_noeud][arret.numeroBus] instanceof Bus))
									{
										// Création d'un nouveau guide et d'un nouveau bus.
										_global.hauteur++;
										var nouveau_guide = thisObj.m_nom_guideline  + "_bus" + arret.numeroBus +_global.hauteur;
										_root.carteswf[thisObj.m_nom_guideline].duplicateMovieClip(nouveau_guide, _global.hauteur);
										_root.carteswf[nouveau_guide].stop();
										_root.carteswf[nouveau_guide]._visible = false;
										_root.carteswf[nouveau_guide]._x = _root.carteswf[thisObj.m_nom_guideline]._x;
										_root.carteswf[nouveau_guide]._y = _root.carteswf[thisObj.m_nom_guideline]._y;
										
										// On ajoute a la liste des movie clip des guides le nouveau clip
										thisObj.m_mc_bus.push(_root.carteswf[nouveau_guide]);
										
										// On crée le bus.
										thisObj.m_jours[date_noeud][arret.numeroBus] = new Bus(thisObj.m_nom_guideline, nouveau_guide, thisObj.m_nb_frames);
									}
									
									// On ajoute le nouvel arret au bus correspondant.
									thisObj.m_jours[date_noeud][arret.numeroBus].addArret(arret);
								}
								else
								{
									trace("Element inconnu ou mal placé : Xml = " + xml_path + " Element : " + node.childNodes[j].nodeName);
								}
							}
							
							// Une fois l'ensemble des arrets pour un bus trouvés alors on
							// peu générer via initArretArrivee l'indice de l'arret d'arrivée.
							for(var k = 0; k < thisObj.m_jours[date_noeud].length; k++)
							{
								if((thisObj.m_jours[date_noeud][k] instanceof Bus))
								{
									thisObj.m_jours[date_noeud][k].initArretArrivee();
								}
							}
							
							break;
						default:
							trace("Element inconnu : Xml = " + xml_path + " Element : " + racine.childNodes[i].nodeName);
					}
	  			}
			}
			
			// On remplit la liste de choix permettant de sélectionner la date.
			_root.remplirDates();
		}
		
		// Gestion des erreurs de chargement du xml.
		donnees_xml.load(xml_path);
		if(donnees_xml.status == -7)
		{
			trace("Parse error, out of memory : " + xml_path);
			return false;
		}
		else if(donnees_xml.status < 0)
		{
			trace("Parse error : " + donnees_xml.status + " " + xml_path);
			return false;
		}
		else 
		{
			return true;
		}
	}
	
	/* Accesseurs */
	public function get jours():Object
	{
		return m_jours;
	}
	
	public function get nbFrames():Number
	{
		return m_nb_frames;
	}
	
	public function get nomGuideline():String
	{
		return m_nom_guideline;
	}
	
	public function get numeroLigne():Number
	{
		return m_numero_ligne;
	}
	
	public function get dates():Array
	{
		return m_liste_jours;
	}
}